==> activity-common-api-1.1.34-20180711.055829-10-sources.jar: cn/com/duiba/activity/common/center/api/dto/ConsumerShareCodeInfoDto.java <==
package cn.com.duiba.activity.common.center.api.dto;

import cn.com.duiba.activity.common.center.api.enums.ShareCodeActivityTypeEnum;

import java.io.Serializable;

/**
 * Created by sty on 2/2/18.
 */
public class ConsumerShareCodeInfoDto implements Serializable {
    private static final long serialVersionUID = -2892960668891936429L;

    /**
     * 用户的id
     */
    private Long consumerId;

    /**
     * 用户的分享码
     */
    private String shareCode;

    /**
     * 活动类型
     */
    private ShareCodeActivityTypeEnum shareCodeActivityTypeEnum;
    /**
     * 活动id
     */
    private Long activityId;

    /**
     * appID
     */
    private Long appId;

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public String getShareCode() {
        return shareCode;
    }

    public void setShareCode(String shareCode) {
        this.shareCode = shareCode;
    }

    public ShareCodeActivityTypeEnum getShareCodeActivityTypeEnum() {
        return shareCodeActivityTypeEnum;
    }

    public void setShareCodeActivityTypeEnum(ShareCodeActivityTypeEnum shareCodeActivityTypeEnum) {
        this.shareCodeActivityTypeEnum = shareCodeActivityTypeEnum;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }
}

==> activity-common-api-1.4.31-sources.jar: cn/com/duiba/activity/common/center/api/dto/ConsumerShareCodeInfoDto.java <==
package cn.com.duiba.activity.common.center.api.dto;

import cn.com.duiba.activity.common.center.api.enums.ShareCodeActivityTypeEnum;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by sty on 2/2/18.
 */
public class ConsumerShareCodeInfoDto implements Serializable {
    private static final long serialVersionUID = -2892960668891936429L;

    /**
     * 用户的id
     */
    private Long consumerId;

    /**
     * 用户的分享码
     */
    private String shareCode;

    /**
     * 活动类型
     */
    private ShareCodeActivityTypeEnum shareCodeActivityTypeEnum;
    /**
     * 活动id
     */
    private Long activityId;

    /**
     * appID
     */
    private Long appId;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public String getShareCode() {
        return shareCode;
    }

    public void setShareCode(String shareCode) {
        this.shareCode = shareCode;
    }

    public ShareCodeActivityTypeEnum getShareCodeActivityTypeEnum() {
        return shareCodeActivityTypeEnum;
    }

    public void setShareCodeActivityTypeEnum(ShareCodeActivityTypeEnum shareCodeActivityTypeEnum) {
        this.shareCodeActivityTypeEnum = shareCodeActivityTypeEnum;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }
}
